class VorbisTools < Formula
  desc "Ogg Vorbis CODEC tools"
  homepage "https://github.com/xiph/vorbis-tools"
  url "https://downloads.xiph.org/releases/vorbis/vorbis-tools-1.4.2.tar.gz", using: :homebrew_curl
  mirror "https://ftp.osuosl.org/pub/xiph/releases/vorbis/vorbis-tools-1.4.2.tar.gz"
  sha256 "db7774ec2bf2c939b139452183669be84fda5774d6400fc57fde37f77624f0b0"
  license all_of: [
    "LGPL-2.0-or-later", # intl/ (libintl)
    "GPL-2.0-or-later", # share/
    "GPL-2.0-only", # oggenc/, vorbiscomment/
  ]
  revision 1

  livecheck do
    url "https://ftp.osuosl.org/pub/xiph/releases/vorbis/?C=M&O=D"
    regex(/href=.*?vorbis-tools[._-]v?(\d+(?:\.\d+)+)\.t/i)
  end

  depends_on "pkg-config" => :build
  depends_on "flac"
  depends_on "libao"
  depends_on "libogg"
  depends_on "libvorbis"

  uses_from_macos "curl"

  on_monterey :or_newer do
    depends_on "autoconf" => :build
    depends_on "automake" => :build
    depends_on "libtool" => :build

    # Fix mistaken recursive `.a` files.
    patch :DATA
  end

  def install
    # Prevent linkage with Homebrew Curl on macOS because of `using: :homebrew_curl` above.
    if OS.mac?
      ENV.remove "HOMEBREW_DEPENDENCIES", "curl"
      ENV.remove "HOMEBREW_INCLUDE_PATHS", Formula["curl"].opt_include
      ENV.remove "HOMEBREW_LIBRARY_PATHS", Formula["curl"].opt_lib
    end

    # Workaround for Xcode 14 ld.
    system "autoreconf", "--force", "--install", "--verbose" if MacOS.version >= :monterey

    # Work around "-Werror,-Wimplicit-function-declaration" issues with
    # configure scripts on Xcode 14:
    ENV.append "CFLAGS", "-Wno-implicit-function-declaration"

    system "./configure", *std_configure_args, "--disable-nls"
    system "make", "install"
  end

  test do
    system bin/"oggenc", test_fixtures("test.wav"), "-o", "test.ogg"
    assert_predicate testpath/"test.ogg", :exist?
    output = shell_output("#{bin}/ogginfo test.ogg")
    assert_match "20.625000 kb/s", output
  end
end

__END__
diff --git a/share/Makefile.am b/share/Makefile.am
index 1011f1d..bd69a67 100644
--- a/share/Makefile.am
+++ b/share/Makefile.am
@@ -11,7 +11,7 @@ libgetopt_a_SOURCES = getopt.c getopt1.c
 libbase64_a_SOURCES = base64.c
 
 libpicture_a_SOURCES = picture.c
-libpicture_a_LIBADD = libbase64.a
+libpicture_a_LIBADD = base64.o
 
 EXTRA_DIST = charmaps.h makemap.c charset_test.c charsetmap.h
 
